@@ -10,7 +10,8 @@ import pandas as pd
 from typing_extensions import Self
 
 import dascore as dc
-from dascore.constants import PatchType, SpoolType, numeric_types, timeable_types
+from dascore.constants import PatchType, numeric_types, timeable_types
+from dascore.exceptions import InvalidSpoolError
 from dascore.utils.chunk import ChunkManager
 from dascore.utils.docs import compose_docstring
 from dascore.utils.mapping import FrozenDict
@@ -38,7 +39,7 @@ class BaseSpool(abc.ABC):
     def __iter__(self) -> PatchType:
         """Iterate through the Patches in the spool."""
 
-    def update(self: SpoolType) -> Self:
+    def update(self) -> Self:
         """
         Updates the contents of the spool and returns a spool.
         """
@@ -46,7 +47,7 @@ class BaseSpool(abc.ABC):
 
     @abc.abstractmethod
     def chunk(
-        self: SpoolType,
+        self,
         overlap: Optional[Union[numeric_types, timeable_types]] = None,
         keep_partial: bool = False,
         snap_coords: bool = True,
@@ -76,13 +77,13 @@ class BaseSpool(abc.ABC):
         """
 
     @abc.abstractmethod
-    def select(self: SpoolType, **kwargs) -> Self:
+    def select(self, **kwargs) -> Self:
         """
         Select only part of the data.
         """
 
     @abc.abstractmethod
-    def get_contents(self: SpoolType) -> pd.DataFrame:
+    def get_contents(self) -> pd.DataFrame:
         """
         Get a dataframe of the patches that will be returned by the spool.
         """
@@ -212,7 +213,7 @@ class DataFrameSpool(BaseSpool):
 
     @compose_docstring(doc=BaseSpool.chunk.__doc__)
     def chunk(
-        self: SpoolType,
+        self,
         overlap: Optional[Union[numeric_types, timeable_types]] = None,
         keep_partial: bool = False,
         snap_coords: bool = True,
@@ -295,7 +296,7 @@ class MemorySpool(DataFrameSpool):
 
 
 @singledispatch
-def spool(obj: Union[Path, str, BaseSpool, Sequence[PatchType]], **kwargs) -> SpoolType:
+def spool(obj: Union[Path, str, BaseSpool, Sequence[PatchType]], **kwargs) -> BaseSpool:
     """
     Load a spool from some data source.
 
@@ -318,7 +319,6 @@ def spool_from_str(path, **kwargs):
         from dascore.clients.dirspool import DirectorySpool
 
         return DirectorySpool(path, **kwargs)
-
     # A single file was passed. If the file format supports quick scanning
     # Return a FileSpool (lazy file reader), else return DirectorySpool.
     elif path.exists():  # a single file path was passed.
@@ -334,7 +334,11 @@ def spool_from_str(path, **kwargs):
         else:
             return MemorySpool(dc.read(path, _format, _version))
     else:
-        raise ValueError(f"could not get spool from {path}")
+        msg = (
+            f"could not get spool from argument: {path}. "
+            f"If it is a path, it may not exist."
+        )
+        raise InvalidSpoolError(msg)
 
 
 @spool.register(BaseSpool)
