@@ -35,7 +35,7 @@ class Terra15FormatterV4(FiberIO):
             with open_hdf5_file(path, "r") as fi:
                 version_str = _get_terra15_version_str(fi)
                 if version_str:
-                    return ("TERRA15", version_str)
+                    return (self.name, version_str)
         except (HDF5ExtError, OSError, IndexError, KeyError, NoSuchNodeError):
             return False
 
@@ -68,3 +68,11 @@ class Terra15FormatterV5(Terra15FormatterV4):
     """
 
     version = "5"
+
+
+class Terra15FormatterV6(Terra15FormatterV4):
+    """
+    Support for Terra15 data format, version 5.
+    """
+
+    version = "6"
