@@ -7,6 +7,7 @@ from dascore.utils.misc import MethodNameSpace
 
 from .spectrogram import spectrogram
 from .waterfall import waterfall
+from .wiggle import wiggle
 
 
 class VizPatchNameSpace(MethodNameSpace):
@@ -14,3 +15,4 @@ class VizPatchNameSpace(MethodNameSpace):
 
     waterfall = waterfall
     spectrogram = spectrogram
+    wiggle = wiggle
