@@ -9,10 +9,10 @@ import numpy as np
 from dascore.constants import PatchType
 from dascore.utils.patch import patch_function
 from dascore.utils.plotting import (
-    _add_time_axis_label,
     _format_time_axis,
     _get_ax,
     _get_cmap,
+    _get_dim_label,
     _get_extents,
 )
 
@@ -39,12 +39,10 @@ def waterfall(
     patch: PatchType,
     ax: Optional[plt.Axes] = None,
     cmap="bwr",
-    timefmt="%H:%M:%S",
     scale: Optional[Union[float, Sequence[float]]] = None,
     scale_type: Literal["relative", "absolute"] = "relative",
-    colorbar=True,
     show=False,
-) -> plt.Figure:
+) -> plt.Axes:
     """
     Parameters
     ----------
@@ -54,8 +52,6 @@ def waterfall(
         A matplotlib object, if None create one.
     cmap
         A matplotlib colormap string or instance.
-    timefmt
-        The format for the time axis.
     scale
         If not None, controls the saturation level of the colorbar.
         Values can either be a float, to set upper and lower limit to the same
@@ -67,8 +63,6 @@ def waterfall(
         are:
             relative - scale based on half the dynamic range in patch
             absolute - scale based on absolute values provided to `scale`
-    colorbar
-        If True, show the color bar.
     show
         If True, show the plot, else just return axis.
 
@@ -92,13 +86,11 @@ def waterfall(
     if scale is not None:
         _set_scale(im, scale, scale_type, patch)
     for dim, x in zip(dims_r, ["x", "y"]):
-        getattr(ax, f"set_{x}label")(str(dim).capitalize())
+        getattr(ax, f"set_{x}label")(_get_dim_label(patch, dim))
     if "time" in dims_r:
-        _format_time_axis(ax, dims_r, timefmt)
-        _add_time_axis_label(ax, patch, dims_r)
+        _format_time_axis(ax, dims_r)
     # add color bar
-    if colorbar:
-        ax.get_figure().colorbar(im)
+    ax.get_figure().colorbar(im)
     ax.invert_yaxis()  # invert y axis so origin is at top
     if show:
         plt.show()
