@@ -41,23 +41,10 @@ def pytest_addoption(parser):
         default=False,
         help="Run integration tests",
     )
-    parser.addoption(
-        "--gui", action="store_true", default=False, help="only run gui tests"
-    )
 
 
 def pytest_collection_modifyitems(config, items):
     """Configure pytest command line options."""
-    # skip workbench gui tests unless --gui is specified.
-    run_guis = config.getoption("--gui")
-    skip = pytest.mark.skip(reason="only run manual tests when --gui is used")
-    for item in items:
-        # skip all gui tests if gui flag is not set
-        if not run_guis and "gui" in item.keywords:
-            item.add_marker(skip)
-        # skip all non-gui tests if gui flag is set
-        if run_guis and "gui" not in item.keywords:
-            item.add_marker(skip)
 
     marks = {}
     if not config.getoption("--integration"):
@@ -85,7 +72,6 @@ def pytest_sessionstart(session):
 
     # need to set nodes to 32 to avoid crash on p3.11. See pytables#977.
     tables.parameters.NODE_CACHE_SLOTS = 32
-    matplotlib.use("Agg")
 
     # Ensure debug is set. This disables progress bars which disrupt debugging.
     dc._debug = True
@@ -117,6 +103,36 @@ def terra15_v5_path():
     return fetch("terra15_v5_test_file.hdf5")
 
 
+@pytest.fixture(scope="class")
+def terra15_v6_path():
+    """Get the path to terra15 V5 file, download if not cached."""
+    return fetch("terra15_v6_test_file.hdf5")
+
+
+@pytest.fixture(scope="session")
+def prodml_v2_0_example_path():
+    """Return the path to the prodml v2.0 file."""
+    out = fetch("prodml_2.0.h5")
+    assert out.exists()
+    return out
+
+
+@pytest.fixture(scope="session")
+def prodml_v2_1_example_path():
+    """Return the path to the prodml v2.1 file."""
+    out = fetch("prodml_2.1.h5")
+    assert out.exists()
+    return out
+
+
+@pytest.fixture(scope="session")
+def idas_h5_example_path():
+    """Return the path to the example terra15 file."""
+    out = fetch("iDAS005_hdf5_example.626.h5")
+    assert out.exists()
+    return out
+
+
 @pytest.fixture()
 @register_func(SPOOL_FIXTURES)
 def terra15_das_spool(terra15_das_example_path) -> SpoolType:
@@ -138,6 +154,22 @@ def terra15_das_patch(terra15_das_example_path) -> Patch:
     return out
 
 
+@pytest.fixture(scope="session")
+@register_func(PATCH_FIXTURES)
+def prodml_v2_0_patch(prodml_v2_0_example_path) -> Patch:
+    """Read the prodML v2.0 patch"""
+    out = read(prodml_v2_0_example_path, "prodml")[0]
+    return out
+
+
+@pytest.fixture(scope="session")
+@register_func(PATCH_FIXTURES)
+def prodml_v2_1_patch(prodml_v2_1_example_path) -> Patch:
+    """Read the prodML v2.1 patch"""
+    out = read(prodml_v2_1_example_path, "prodml")[0]
+    return out
+
+
 @pytest.fixture(scope="session")
 @register_func(PATCH_FIXTURES)
 def random_patch() -> Patch:
@@ -165,6 +197,14 @@ def multi_dim_coords_patch(random_patch):
     return out
 
 
+@pytest.fixture(scope="session")
+@register_func(PATCH_FIXTURES)
+def event_patch_1():
+    """Fetch event patch 1."""
+    path = fetch("example_dasdae_event_1.h5")
+    return dc.spool(path)[0]
+
+
 @pytest.fixture(scope="class", params=PATCH_FIXTURES)
 def patch(request):
     """A meta-fixtures for collecting all patches used in testing."""
@@ -249,7 +289,7 @@ def adjacent_spool_no_overlap(random_patch) -> dc.BaseSpool:
 
 @pytest.fixture(scope="class")
 @register_func(SPOOL_FIXTURES)
-def one_file_file_spool(one_file_dir):
+def one_file_directory_spool(one_file_dir):
     """Create a directory with a single DAS file."""
     return DirectorySpool(one_file_dir).update()
 
@@ -277,6 +317,13 @@ def basic_file_spool(two_patch_directory):
     return out.update()
 
 
+@pytest.fixture(scope="class")
+@register_func(SPOOL_FIXTURES)
+def terra15_file_spool(terra15_v5_path):
+    """A file spool for terra15."""
+    return dc.spool(terra15_v5_path)
+
+
 @pytest.fixture(scope="class", params=SPOOL_FIXTURES)
 def spool(request):
     """A meta-fixtures for collecting all spools used in testing."""
