@@ -1,6 +1,4 @@
-"""
-Tests module for wave format.
-"""
+"""Tests module for wave format."""
 from pathlib import Path
 
 import pytest
@@ -14,7 +12,7 @@ class TestWriteWav:
 
     @pytest.fixture(scope="class")
     def audio_patch(self):
-        """Return the example sin wave patch"""
+        """Return the example sin wave patch."""
         return dc.get_example_patch("sin_wav", sample_rate=500)
 
     @pytest.fixture(scope="class")
@@ -25,19 +23,19 @@ class TestWriteWav:
         return new
 
     def test_directory(self, wave_dir, audio_patch):
-        """Sanity checks on wav directory"""
+        """Sanity checks on wav directory."""
         assert wave_dir.exists()
         wavs = list(wave_dir.rglob("*.wav"))
         assert len(wavs) == len(audio_patch.coords["distance"])
 
     def test_write_single_file(self, audio_patch, tmp_path_factory):
-        """Ensure a single file can be written"""
+        """Ensure a single file can be written."""
         path = tmp_path_factory.mktemp("wave_temp") / "temp.wav"
         dc.write(audio_patch, path, "wav")
         assert path.exists()
 
     def test_resample(self, audio_patch, tmp_path_factory):
-        """Ensure resampling changes sampling rate in file"""
+        """Ensure resampling changes sampling rate in file."""
         path = tmp_path_factory.mktemp("wav_resample") / "resampled.wav"
         dc.write(audio_patch, path, "wav", resample_frequency=1000)
         (sr, ar) = read_wav(str(path))
